From: Andrew Morton <akpm@linux-foundation.org>
To: pratmal@google.com
Cc: vbabka@kernel.org, david@kernel.org, sj@kernel.org,
corbet@lwn.net, ljs@kernel.org, skhan@linuxfoundation.org,
anshuman.khandual@arm.com, gthelen@google.com, surenb@google.com,
mhocko@suse.com, jackmanb@google.com, hannes@cmpxchg.org,
ziy@nvidia.com, liam@infradead.org, rppt@kernel.org,
linux-mm@kvack.org, linux-kernel@vger.kernel.org,
linux-doc@vger.kernel.org
Subject: Re: [PATCH v4] mm/page_reporting: Add page_reporting_delay_ms module parameter
Date: Fri, 31 Jul 2026 14:34:20 -0700 [thread overview]
Message-ID: <20260731143420.0787387ce2ca120ecee15338@linux-foundation.org> (raw)
In-Reply-To: <20260731193705.2902728-1-pratmal@google.com>
On Fri, 31 Jul 2026 19:37:05 +0000 pratmal@google.com wrote:
> Free page reporting currently hardcodes a 2-second interval between
> reports. This rigid delay cannot accommodate diverse guest workloads.
>
> This patch introduces a module parameter, page_reporting_delay_ms
> (default: 2000), allowing users to tune the reporting rate:
> - Lower values enable aggressive memory reclamation by returning unused
> pages to the host immediately.
> - Higher values help batch pages during spiky allocation/free churn,
> reducing hypercalls and nested page fault overheads.
>
> Setting the delay to 0 is safe and execution is strictly gated by:
> - reporting is only triggered by high-order page frees.
> - expensive hypercalls are bounded by a slot capacity watermark check
> before proceeding.
This conflcits with the just-upstreamed 0b45f6927a1
("mm/page_reporting: use system_freezable_wq to fix UAF during
suspend")
(https://lore.kernel.org/20260721005603.1710551-1-linkl@google.com).
Please review my resolution:
--- a/mm/page_reporting.c~mm-page_reporting-add-page_reporting_delay_ms-module-parameter
+++ a/mm/page_reporting.c
@@ -48,7 +48,11 @@ MODULE_PARM_DESC(page_reporting_order, "
*/
EXPORT_SYMBOL_GPL(page_reporting_order);
-#define PAGE_REPORTING_DELAY (2 * HZ)
+static unsigned int page_reporting_delay_ms = 2 * MSEC_PER_SEC;
+module_param(page_reporting_delay_ms, uint, 0644);
+MODULE_PARM_DESC(page_reporting_delay_ms,
+ "Set page reporting delay in milliseconds");
+
static struct page_reporting_dev_info __rcu *pr_dev_info __read_mostly;
enum {
@@ -57,6 +61,13 @@ enum {
PAGE_REPORTING_ACTIVE
};
+/* schedule work for page reporting */
+static void page_reporting_schedule_work(struct page_reporting_dev_info *prdev)
+{
+ queue_delayed_work(system_freezable_wq, &prdev->work,
+ msecs_to_jiffies(page_reporting_delay_ms));
+}
+
/* request page reporting */
static void
__page_reporting_request(struct page_reporting_dev_info *prdev)
@@ -77,12 +88,10 @@ __page_reporting_request(struct page_rep
return;
/*
- * Delay the start of work to allow a sizable queue to build. For
- * now we are limiting this to running no more than once every
- * couple of seconds.
+ * Delay the start of work to allow a sizable queue to build.
+ * We limit this based on page_reporting_delay_ms.
*/
- queue_delayed_work(system_freezable_wq, &prdev->work,
- PAGE_REPORTING_DELAY);
+ page_reporting_schedule_work(prdev);
}
/* notify prdev of free page reporting request */
@@ -337,13 +346,12 @@ static void page_reporting_process(struc
err_out:
/*
* If the state has reverted back to requested then there may be
* additional pages to be processed. We will defer for 2s to allow
* more pages to accumulate.
*/
state = atomic_cmpxchg(&prdev->state, state, PAGE_REPORTING_IDLE);
if (state == PAGE_REPORTING_REQUESTED)
- queue_delayed_work(system_freezable_wq, &prdev->work,
- PAGE_REPORTING_DELAY);
+ page_reporting_schedule_work(prdev);
}
static DEFINE_MUTEX(page_reporting_mutex);
_
next prev parent reply other threads:[~2026-07-31 21:34 UTC|newest]
Thread overview: 6+ messages / expand[flat|nested] mbox.gz Atom feed top
2026-07-31 19:37 pratmal
2026-07-31 21:34 ` Andrew Morton [this message]
2026-07-31 21:41 ` Pratyush Mallick
2026-08-05 12:03 ` David Hildenbrand (Arm)
2026-08-01 0:02 ` SJ Park
2026-08-01 9:25 ` Lorenzo Stoakes (ARM)
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20260731143420.0787387ce2ca120ecee15338@linux-foundation.org \
--to=akpm@linux-foundation.org \
--cc=anshuman.khandual@arm.com \
--cc=corbet@lwn.net \
--cc=david@kernel.org \
--cc=gthelen@google.com \
--cc=hannes@cmpxchg.org \
--cc=jackmanb@google.com \
--cc=liam@infradead.org \
--cc=linux-doc@vger.kernel.org \
--cc=linux-kernel@vger.kernel.org \
--cc=linux-mm@kvack.org \
--cc=ljs@kernel.org \
--cc=mhocko@suse.com \
--cc=pratmal@google.com \
--cc=rppt@kernel.org \
--cc=sj@kernel.org \
--cc=skhan@linuxfoundation.org \
--cc=surenb@google.com \
--cc=vbabka@kernel.org \
--cc=ziy@nvidia.com \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -337,13 +346,12 @@ static void page_reporting_process(struc
/*
* If the state has reverted back to requested then there may be
- * additional pages to be processed. We will defer for 2s to allow
- * more pages to accumulate.
+ * additional pages to be processed. We will defer by
+ * page_reporting_delay_ms to allow more pages to accumulate.
*/
state = atomic_cmpxchg(&prdev->state, state, PAGE_REPORTING_IDLE);
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
all inboxes | Powered by JetHome®